package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.DataElement;
import com.ynet.gene.data.DataField;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.Trace;
import com.ynet.util.formula.CFormula;
import com.ynet.util.formula.FormulaException;
import com.ynet.util.formula.FormulaValue;
import com.ynet.util.formula.LexicalAnalyser;
import com.ynet.util.formula.VariableController;
import com.ynet.util.formula.function.Function;
import com.ynet.util.formula.function.FunctionManager;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/ICollProcessAction.class */
public class ICollProcessAction extends LifeAction {
    private String iCollName;
    private String beginPosFieldName = "turnPageBeginPos";
    private String showNumFieldName = "turnPageShowNum";
    private String queryFields;
    private Map fieldMap;
    private String expression;

    public String getExpression() {
        return this.expression;
    }

    public void setExpression(String expression) {
        this.expression = expression;
    }

    public String getQueryFields() {
        return this.queryFields;
    }

    public String getICollName() {
        return this.iCollName;
    }

    public void setICollName(String iCollName) {
        this.iCollName = iCollName;
    }

    public void setQueryFields(String queryFields) {
        this.queryFields = queryFields;
        if (this.fieldMap == null) {
            this.fieldMap = new HashMap();
            StringTokenizer st = new StringTokenizer(queryFields, "|");
            while (st.hasMoreTokens()) {
                String[] field = st.nextToken().split(",");
                this.fieldMap.put(field[0], field[1]);
            }
        }
    }

    public String execute(Context context) throws GENEException {
        filterIcol(context);
        sortIcol(context);
        retrievePageIcol(context);
        return "0";
    }

    private void filterIcol(Context context) throws GENEException {
        IndexedCollection ictmp;
        IndexedCollection icol = context.getDataElement(this.iCollName);
        if (this.expression != null) {
            IndexedCollection indexedCollection = new IndexedCollection(this.iCollName);
            ictmp = indexedCollection;
            indexedCollection.setDataElement((DataElement) icol.getDataElement().clone());
            Iterator it = icol.iterator();
            while (it.hasNext()) {
                Object tmpIcolObj = it.next();
                if ((tmpIcolObj instanceof KeyedCollection) && getFormulaValue((KeyedCollection) tmpIcolObj, context)) {
                    ictmp.add(tmpIcolObj);
                }
            }
        } else {
            ictmp = (IndexedCollection) icol.clone();
        }
        context.removeDataElement(this.iCollName);
        context.setDataValue("turnPageTotalNum", Integer.valueOf(ictmp.size()));
        context.addDataElement(ictmp);
    }

    private boolean getFormulaValue(final KeyedCollection kcol, final Context context) {
        if (this.expression != null && this.expression.length() != 0) {
            LexicalAnalyser lexical = new LexicalAnalyser();
            CFormula valueFormula = new CFormula();
            try {
                lexical.parseTheFormula(this.expression);
                valueFormula.setVariableController(new VariableController() { // from class: com.ynet.life.action.ICollProcessAction.1
                    public FormulaValue getVariableValue(String variableName) throws Exception {
                        char flag = variableName.charAt(0);
                        String var = variableName.substring(1);
                        if (flag == '$') {
                            FormulaValue formulaValue = new FormulaValue();
                            formulaValue.nDataType = 6;
                            if (var.charAt(0) == '#') {
                                String var2 = var.substring(1);
                                try {
                                    DataElement element = kcol.getDataElement(var2);
                                    if (element instanceof DataField) {
                                        Object value = kcol.getDataValue(var2);
                                        if (value instanceof String) {
                                            formulaValue.sStringValue((String) value);
                                        } else {
                                            formulaValue.setValue(value);
                                        }
                                    } else {
                                        formulaValue.setValue(element);
                                    }
                                } catch (Exception e) {
                                    GENELog.log(GENEConstance.GENE_FORMULA, GENELog.ERROR, 0, "Formula Error in Do transition formula for " + toString(), e);
                                }
                            } else {
                                try {
                                    DataElement element2 = context.getDataElement(var);
                                    if (element2 instanceof DataField) {
                                        Object value2 = context.getDataValue(var);
                                        if (value2 instanceof String) {
                                            formulaValue.sStringValue((String) value2);
                                        } else {
                                            formulaValue.setValue(value2);
                                        }
                                    } else {
                                        formulaValue.setValue(element2);
                                    }
                                } catch (Exception e2) {
                                    GENELog.log(GENEConstance.GENE_FORMULA, GENELog.ERROR, 0, "Formula Error in Do transition formula for " + toString(), e2);
                                }
                            }
                            return formulaValue;
                        }
                        FormulaValue formulaValue2 = new FormulaValue();
                        formulaValue2.nDataType = 6;
                        return formulaValue2;
                    }
                });
                valueFormula.setContent(lexical);
                return valueFormula.getValue().bBooleanValue();
            } catch (Exception e) {
                GENELog.log(GENEConstance.GENE_FORMULA, GENELog.ERROR, 0, "Formula Error in Do transition formula for " + toString(), e);
                return false;
            }
        }
        return false;
    }

    private void sortIcol(Context context) throws ObjectNotFoundException, InvalidArgumentException {
        Object newOrderObj = context.getDataValue("sortKey");
        context.getDataValue("sortDirection");
        if (newOrderObj != null) {
            IndexedCollection icoll = context.getDataElement(this.iCollName);
            IcolComparator comparator = new IcolComparator((String) newOrderObj, this.fieldMap);
            Collections.sort(icoll, comparator);
            Trace.logDebug("LOAF", "排序结果--->\n".concat(String.valueOf(icoll)));
        }
    }

    private void retrievePageIcol(Context context) {
        try {
            IndexedCollection icoll = context.getDataElement(this.iCollName);
            Object orderDirection = context.getDataValue("sortDirection");
            String odSt = "ASC";
            if (orderDirection != null && !orderDirection.equals("ASC")) {
                odSt = "DESC";
            }
            int beginPos = 1;
            int showNum = icoll.size();
            Object tmpBegin = context.get(this.beginPosFieldName);
            if (tmpBegin != null) {
                beginPos = Integer.parseInt((String) tmpBegin);
            }
            Object tmpPageShowNumber = context.get(this.showNumFieldName);
            if (tmpPageShowNumber != null) {
                showNum = Integer.parseInt((String) tmpPageShowNumber);
            }
            int total = icoll.size();
            IndexedCollection pageIcoll = new IndexedCollection(this.iCollName);
            pageIcoll.setDataElement((DataElement) icoll.getDataElement().clone());
            if (odSt.equalsIgnoreCase("ASC")) {
                int i = beginPos + showNum;
                int endPos = i;
                if (i > total) {
                    endPos = total + 1;
                }
                for (int i2 = beginPos - 1; i2 < endPos - 1; i2++) {
                    pageIcoll.addDataElement(icoll.getElementAt(i2));
                }
            } else {
                int i3 = total - beginPos;
                int i4 = i3 - showNum;
                int endPos2 = i4;
                if (i4 < -1) {
                    endPos2 = -1;
                }
                for (int i5 = i3; i5 > endPos2; i5--) {
                    pageIcoll.addDataElement(icoll.getElementAt(i5));
                }
            }
            context.removeDataElement(this.iCollName);
            context.addDataElement(pageIcoll);
        } catch (Exception e) {
            context.printStackTrace();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_ynet_life_action.jar:com/ynet/life/action/ICollProcessAction$IcolComparator.class */
    public static class IcolComparator implements Comparator {
        private String col;
        private String type = "String";
        private Map fieldMap;

        public IcolComparator(String col, Map fieldMap) {
            this.fieldMap = null;
            this.col = col;
            this.fieldMap = fieldMap;
        }

        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Type inference failed for: r0v3 */
        /* JADX WARN: Type inference failed for: r0v40, types: [java.lang.Object] */
        /* JADX WARN: Type inference failed for: r0v41 */
        @Override // java.util.Comparator
        public int compare(Object obj, Object obj2) {
            String str = "";
            String str2 = "";
            Object obj3 = null;
            InvalidArgumentException invalidArgumentException = 0;
            invalidArgumentException = 0;
            String str3 = null;
            try {
                obj3 = ((KeyedCollection) obj).getDataValue(this.col);
                invalidArgumentException = ((KeyedCollection) obj2).getDataValue(this.col);
                str3 = invalidArgumentException;
            } catch (InvalidArgumentException e) {
                invalidArgumentException.printStackTrace();
            } catch (ObjectNotFoundException e2) {
                invalidArgumentException.printStackTrace();
            }
            String str4 = "string";
            try {
                str = (String) obj3;
                str2 = str3;
            } catch (Exception unused) {
            }
            Object obj4 = this.fieldMap.get(this.col);
            if (obj4 != null) {
                str4 = (String) obj4;
            }
            if ("Number".equalsIgnoreCase(str4)) {
                if (str == null || str.equals("")) {
                    str = "0";
                }
                if (str2 == null || str2.equals("")) {
                    str2 = "0";
                }
                return Long.valueOf(str).compareTo(Long.valueOf(str2));
            }
            if (obj3 == null) {
                return 1;
            }
            if (str3 == null) {
                return -1;
            }
            return str.compareTo(str2);
        }
    }

    /* loaded from: com_ynet_life_action.jar:com/ynet/life/action/ICollProcessAction$Like.class */
    private static class Like extends Function {
        private Like() {
        }

        /* synthetic */ Like(Like like) {
            this();
        }

        public FormulaValue getValue(List argList) throws FormulaException {
            FormulaValue stResult = new FormulaValue();
            stResult.nDataType = 6;
            if (argList.size() != 2) {
                throw new FormulaException("Invalid Paramater function Like(object)!");
            }
            FormulaValue left = ((CFormula) argList.get(0)).getValue();
            FormulaValue right = ((CFormula) argList.get(1)).getValue();
            String leftSt = left.getValue().toString();
            String rightSt = right.getValue().toString();
            stResult.nDataType = 3;
            if (leftSt.indexOf(rightSt) == -1) {
                stResult.bBooleanValue(false);
            } else {
                stResult.bBooleanValue(true);
            }
            return stResult;
        }
    }

    static {
        Like lenFunc = new Like(null);
        FunctionManager.registFunction("@Like", lenFunc);
    }
}
